@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -64,4 +64,9 @@ GtkWidget *UIBuilder::GetRefdWidget (char const *wname)
 		return NULL;
 }
 
+GObject *UIBuilder::GetObject (char const *name)
+{
+	return gtk_builder_get_object (m_Builder, name);
+}
+
 }   //  namespace gcu
